# BUGS

- Dynamically scale other columns too (like pending changes window)
- Uncat doesn't update after cat and push (filtered view)
- Escape to exit from filter menu (if no filter needed)
- Escape to clear filters

# Features

- Show in categorizer any categories where this item was placed in the past ie Books [4]
